@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowDel.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowDel extends SyL_AdmFlow
@@ -82,15 +82,10 @@ class SyL_AdmFlowDel extends SyL_AdmFlow
             // 祭ѥ᡼̾
             $key_name = $form->getStructConfig('key_name');
             // ѥ᡼
-            $keys = $data->get($key_name);
-            if (is_string($keys)) {
-                $keys = array($keys);
-            } else {
-                $keys = $data->geta($key_name);
-                if (!is_array($keys)) {
-                    // Բ
-                    SyL_Response::redirect($this->getUrl('lst'));
-                }
+            $keys = $data->geta($key_name);
+            // ѥ᡼å
+            if (!$keys) {
+                SyL_Response::redirect($this->getUrl('lst'));
             }
 
             // DB³
