@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -93,6 +93,13 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         $adm =& SyL_Adm::factory($form, $conn);
         // ơ֥
         $adm->loadConfig();
+        // å
+        if (!$adm->isLst()) {
+            // Բ
+            echo '403 Forbidden';
+            exit;
+        }
+
         // ɽǡ
         $results = $adm->getList($sort, $page, '');
         // Ȥθѥ᡼
