@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -190,6 +190,18 @@ class SyL_AdmOperation
         return array();
     }
 
+    /**
+     * ɽǽȽꤹ
+     *
+     * @access public
+     * @return bool true: ɽǽfalse: ɽԲ
+     */
+    function isLst()
+    {
+        $enable = $this->form->getStructConfig('enable_lst');
+        return ($enable === null) ? true : (bool)$enable;
+    }
+
     /**
      * ϿǽȽꤹ
      *
@@ -271,7 +283,7 @@ class SyL_AdmOperation
                             $valid = false;
                             break;
                         }
-                        $conditions->addEqual($column, $value);
+                        $conditions->addEqual($column, $value, true, false);
                     }
                 } else {
                     $valid = false;
