@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthFile.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthFile.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthFile.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthFile.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthFile extends SyL_Auth
@@ -47,22 +47,11 @@ class SyL_AuthFile extends SyL_Auth
     /**
      * 桼̾ѥɶڤʸ
      *
-     * @access protected
+     * @access private
      * @var string
      */
     var $separater = ':';
 
-    /**
-     * 󥢥Ƚ
-     * 
-     * @access public
-     * @return bool true: 󥢥󤢤ꡢfalse: 󥢥ʤ
-     */
-    function isLoginAction()
-    {
-        return (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$this->username]) && isset($_POST[$this->password]));
-    }
-
     /**
      * ǧڼ¹
      * 
@@ -74,38 +63,38 @@ class SyL_AuthFile extends SyL_Auth
          $client_username = isset($_POST[$this->username]) ? $_POST[$this->username] : '';
          $client_password = isset($_POST[$this->password]) ? $_POST[$this->password] : '';
 
-         $parameters = explode(':', SYL_AUTH_TYPE_PARAMETER, 2);
-         if (!isset($parameters[1])) $parameters[1] = '';
-
          clearstatcache();
 
-         if (!file_exists($parameters[0])) {
-             trigger_error("[SyL error] Auth file not found ({$parameters[0]})", E_USER_ERROR);
+         $passwd_file  = SYL_AUTH_TYPE_PARAMETER;
+         $passwd_file1 = SYL_PROJECT_DIR . '/var/' . $passwd_file;
+         if (!is_file($passwd_file1)) {
+             if (!is_file($passwd_file)) {
+                 trigger_error("[SyL error] Auth file not found ({$passwd_file} or {$passwd_file1})", E_USER_ERROR);
+             }
+             $passwd_file1 = $passwd_file;
          }
-         if (!is_readable($parameters[0])) {
-             trigger_error("[SyL error] Auth file permission denied ({$parameters[0]})", E_USER_ERROR);
+         if (!is_readable($passwd_file1)) {
+             trigger_error("[SyL error] Auth file permission denied ({$passwd_file1})", E_USER_ERROR);
          }
 
-         $find = false;
+         SyL_Loggers::info("[Auth] Password file: {$passwd_file1}");
 
-         $fp = fopen($parameters[0], 'rb');
-         while (!feof($fp)) {
-             $user = explode($this->separater, rtrim(fgets($fp), "\r\n"));
+         $server_password = null;
+         foreach (file($passwd_file1) as $user) {
+             $user = explode($this->separater, rtrim($user), 2);
              if ($user[0] && ($user[0] == $client_username)) {
-                 $server_password = isset($user[1]) ? $user[1] : '';
-                 $find = true;
+                 $server_password = $user[1];
                  break;
              }
          }
-         fclose($fp);
 
-         if (!$find) {
+         if ($server_password === null) {
              // ǧԲ
              $client_username = '';
              $server_password = '';
          }
          // ѥȽ
-         return $this->isLoginPassword($client_username, $client_password, $server_password, (bool)$parameters[1]);
+         return $this->isLoginPassword($client_username, $client_password, $server_password);
     }
 }
 
