@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.6 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.7 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerJs.php,v 1.6 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerJs.php,v 1.7 2007/07/08 04:22:38 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerJs extends SyL_Controller
@@ -67,12 +67,15 @@ class SyL_ControllerJs extends SyL_Controller
     {
         $config_files = array();
         // ץꥱե륿ե
-        $config_files['filters'][] = SYL_APP_DIR . "/{$this->filter_file_name}";
-        if (!file_exists($config_files['filters'][0])) {
-            array_shift($config_files['filters']);
+        $filter = SYL_APP_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
         }
         // Хե륿ե
-        $config_files['filters'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
+        $filter = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
+        }
 
         // ٥ȼ¹
         $this->raiseEvent('loadStream', $config_files);
