@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_FilterAuth.php,v 1.5 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_FilterAuth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_FilterAuth extends SyL_Filter
@@ -79,32 +79,33 @@ class SyL_FilterAuth extends SyL_Filter
     {
         // ǧڥ֥Ⱥ
         $this->auth =& SyL_Auth::singleton();
-        list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER, 2);
-        // ǧڥѥ᡼̾å
-        $this->auth->setUserParamaterName($username);
-        $this->auth->setPasswordParamaterName($password);
     }
 
     /**
      * ǧȽ or ǧڼ¹
      *
      * @access public
+     * @param object ǡ֥
      */
-    function preAction()
+    function preAction(&$data)
     {
         // ǧڥꥢȽ
         if ($this->auth->isAuthArea()) {
-            // ֤Ƚ
-            if (!$this->auth->isLogin()) {
-                // å󥨥顼̤إ쥯
-                $this->auth->redirectSessionError();
-            }
-        } else {
-            // ̤ξ
             // 󥢥Ƚ
             if ($this->auth->isLoginAction()) {
                 // ¹
                 $this->login = $this->auth->doLogin();
+                if (!$this->login) {
+                    // å󥨥顼̤إ쥯
+                    SyL_Auth::redirectSessionError('login=false');
+                }
+            } else {
+                // ֤Ƚ
+                if (!$this->auth->isLogin()) {
+                    // ̤ξ
+                    // å󥨥顼̤إ쥯
+                    SyL_Auth::redirectSessionError();
+                }
             }
         }
     }
@@ -113,14 +114,14 @@ class SyL_FilterAuth extends SyL_Filter
      * ϡTOP̤˥쥯
      *
      * @access public
-     * @param object ǡޥ͡㥪֥
+     * @param object ǡ֥
      */
-    function postAction(&$context)
+    function postAction(&$data)
     {
         // ǧڥꥢȽ
         if (is_bool($this->login) && $this->login) {
             // TOPإ쥯
-            $context->setRedirectUrl(SyL_Auth::getRedirectUrl());
+            SyL_Auth::redirectTop();
         }
     }
 }
