@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.5 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.5 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.6 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -64,14 +64,14 @@ class SyL_Auth
      * @access private
      * @var string
      */
-    var $username = 'username';
+    var $username = 'login_username';
     /**
      * ѥɥѥ᡼̾
      * 
      * @access private
      * @var string
      */
-    var $password = 'passwd';
+    var $password = 'login_passwd';
     /**
      * ѥǧڤŹ沽ϥå岽ƹԤ
      *
@@ -90,42 +90,53 @@ class SyL_Auth
     var $challenge_response_session_name = 'syl_auth_challenge';
 
     /**
-     * SyL_Auth饹Υ󥹥󥹼
-     *
-     * singletonǥѤƤΤǡ
-     * 1ĤΥ󥹥󥹤λȤ롣
-     *
-     * ˡ
-     *   $SyL_Auth =& SyL_Auth::singleton();
+     * 󥹥ȥ饯
      *
      * @access public
      */
-    function &singleton()
+    function SyL_Auth()
     {
-        static $singleton;
-        if (!is_object($singleton)) {
-            list($type) = explode(':', SYL_AUTH_TYPE, 2);
-            $singleton = SyL_Auth::createAuth($type);
-        }
-        return $singleton;
+        list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER, 2);
+        // ǧڥѥ᡼̾å
+        $this->setUserParamaterName($username);
+        $this->setPasswordParamaterName($password);
     }
 
     /**
-     * ǧڥ֥Ȥ
-     * 
-     * @static
-     * @access protected
+     * SyL_Auth饹Υ󥹥󥹼
+     *
+     * @access public
      * @param string ǧڥ
      * @return object ǧڥ֥
      */
-    function createAuth($type)
+    function &singleton($type='')
     {
-        $classname = 'SyL_Auth' . ucfirst($type);
-        include_once SYL_INCLUDE_DIR . "/framework/Auth/{$classname}.php";
-        $obj = new $classname();
-        $request =& SyL_Request::singleton();
-        $obj->session =& $request->getSessionObject();
-        return $obj;
+        static $singleton = array();
+        if (!$type) {
+            list($type) = explode(':', SYL_AUTH_TYPE, 2);
+        }
+
+        if (!isset($singleton[$type])) {
+            SyL_Loggers::info("[Auth] Type {$type}");
+
+            $classname = 'SyL_Auth' . ucfirst($type);
+            include_once SYL_INCLUDE_DIR . "/framework/Auth/{$classname}.php";
+            $request =& SyL_Request::singleton();
+            $singleton[$type] = new $classname();
+            $singleton[$type]->setSessionObject($request->getSessionObject());
+        }
+        return $singleton[$type];
+    }
+
+    /**
+     * å󥪥֥Ȥ򥻥åȤ
+     * 
+     * @access private
+     * @param object å󥿥
+     */
+    function setSessionObject(&$session)
+    {
+        $this->session =& $session;
     }
 
     /**
@@ -180,8 +191,14 @@ class SyL_Auth
      */
     function isAuthArea()
     {
+        $session_error_url = call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl'));
+        if ($_SERVER['PHP_SELF'] == $session_error_url) {
+            return false;
+        }
+
         $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '/';
-        return (bool)preg_match('/^' . preg_quote(SyL_Auth::getRedirectUrl(), '/') . '/', $request_uri);
+        $auth_url    = call_user_func(array(__CLASS__, 'getAuthUrl'));
+        return (bool)preg_match('/^' . preg_quote($auth_url, '/') . '/', $request_uri);
     }
 
     /**
@@ -192,7 +209,7 @@ class SyL_Auth
      */
     function isLoginAction()
     {
-        return false;
+        return (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$this->username]) && isset($_POST[$this->password]));
     }
 
     /**
@@ -213,10 +230,10 @@ class SyL_Auth
      * @param string 饤桼̾
      * @param string 饤ѥ
      * @param string С¦ѥ
-     * @param bool С¦ϥåե饰
+     * @param string С¦ϥå岽ˡ
      * @return bool OK: ǧOK, NG: ǧNG
      */
-    function isLoginPassword($client_username, $client_password, $server_password, $server_hash)
+    function isLoginPassword($client_username, $client_password, $server_password)
     {
         if (!$this->isLoginAction()) {
             SyL_Loggers::warn("[Auth] Login Failed. No Login Action. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
@@ -227,25 +244,66 @@ class SyL_Auth
             return false;
         }
 
-        if (SYL_AUTH_PASSWORD_HASH) {
-            // 饤¦ : md5(  md5(ѥ))
-            // С¦     : md5(  ѥ) or md5(  md5(ѥ))
+        // ѥɥϥå岽
+        $hashes = array_map('trim', explode(':', SYL_AUTH_PASSWORD_HASH));
+        if ((count($hashes) == 2) && ($hashes[0] || $hashes[1])) {
             $challenge = $this->getChallengeCode();
-            if ($challenge === null) {
-                trigger_error("[SyL error] Unable to get of Challenge Code", E_USER_ERROR);
+            if ($hashes[0] && $hashes[1]) {
+                //  饤ȡʥϥå -> Сʥϥå
+                //    => Τޤ
+                if ($challenge) {
+                    // - 󥸤
+                    //  CL: md5(  md5(ѥ))
+                    //  SV: ѥ == md5(  ѥ)
+                    SyL_Loggers::info("[Auth] Auth hash CL: {$hashes[0]} SV: {$hashes[1]} challenge: on");
+                    $server_password = call_user_func($hashes[0], $challenge . $server_password);
+                } else {
+                    // - 󥸤ʤ
+                    //  CL: md5(ѥ)
+                    //  SV: ѥ == ѥ
+                    SyL_Loggers::info("[Auth] Auth hash CL: {$hashes[0]} SV: {$hashes[1]} challenge: off");
+                }
+            } else if ($hashes[0]) {
+                //  饤ȡʥϥå -> Сʿ
+                //    => С¦ѥɤϥå岽
+                if ($challenge) {
+                    // - 󥸤
+                    //  CL: md5(  md5(ѥ))
+                    //  SV: ѥ == md5(  md5(ѥ))
+                    SyL_Loggers::info("[Auth] Auth hash CL: {$hashes[0]} SV: (none) challenge: on");
+                    $server_password = call_user_func($hashes[0], $server_password);
+                    $server_password = call_user_func($hashes[0], $challenge . $server_password);
+                } else {
+                    // - 󥸤ʤ
+                    //  CL: md5(ѥ)
+                    //  SV: ѥ == md5(ѥ)
+                    SyL_Loggers::info("[Auth] Auth hash CL: {$hashes[0]} SV: (none) challenge: off");
+                    $server_password = call_user_func($hashes[0], $server_password);
+                }
+            } else if ($hashes[1]) {
+                //  饤ȡʿ -> Сʥϥå
+                //    => ѥɤϥå岽
+                //  CL: ʤ
+                //  SV: md5(ѥ)  == ѥ
+                SyL_Loggers::info("[Auth] Auth hash CL: (none) SV: {$hashes[1]} challenge: off");
+                $client_password = call_user_func($hashes[1], $client_password);
+            } else {
+                trigger_error("[SyL error] Unknown auth error", E_USER_ERROR);
             }
-            if (!$server_hash) {
-                $server_password = call_user_func(SYL_AUTH_PASSWORD_HASH, $server_password);
-            }
-            $server_password = call_user_func(SYL_AUTH_PASSWORD_HASH, $challenge . $server_password);
+        } else {
+            //  饤ȡʿ -> Сʿ
+            //    => Τޤ
+            //  CL: ʤ
+            //  SV: ѥ == ѥ
+            SyL_Loggers::info("[Auth] Auth hash CL: (none) SV: (none) challenge: off");
         }
 
-        if ($server_password == $client_password) {
+        if ($server_password === $client_password) {
             $this->session->set($this->session_name, $client_username);
-            SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
+            SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username})");
             return true;
         } else {
-            SyL_Loggers::warn("[Auth] Login Failed. Invalid Password. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
+            SyL_Loggers::warn("[Auth] Login Failed. Invalid Password. (class: " . get_class($this) . " user: {$client_username})");
             return false;
         }
     }
@@ -261,6 +319,17 @@ class SyL_Auth
         return $this->session->is($this->session_name);
     }
 
+    /**
+     * ǧڥå
+     * 
+     * @access public
+     * @return bool OK: ǧOK, NG: ǧNG
+     */
+    function deleteLogin()
+    {
+        $this->session->delete($this->session_name);
+    }
+
     /**
      * ȽԤ
      * 
@@ -271,12 +340,11 @@ class SyL_Auth
     {
         $client_username = $this->session->get($this->session_name);
         SyL_Loggers::info("[Auth] Logout Success. (class: " . get_class($this) . " user: {$client_username})");
-        $this->session->deletes();
+        $this->deleteLogin();
     }
 
     /**
      * 󥸥ɤå˥åȤơ
-     * ASCIIɤΡ'(39)~פޤǤͤǼ
      * 
      * @access public
      * @param string 󥸥ɤη
@@ -311,19 +379,68 @@ class SyL_Auth
      * @static
      * @access public
      */
-    function getRedirectUrl()
+    function getAuthUrl()
     {
-        return SYL_AUTH_URL;
+        $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
+        $script_name = isset($_SERVER['SCRIPT_NAME']) ? $_SERVER['SCRIPT_NAME'] : '';
+        if ($request_uri && $script_name) {
+            if (preg_match ('/^' . preg_quote($script_name, '/') . '/', $request_uri)) {
+                return $script_name . SYL_AUTH_PATHINFO;
+            } else {
+                // ĥҤ̵б
+                $path_parts = pathinfo($script_name);
+                if (isset($path_parts['extension'])) {
+                    $path_parts['basename'] = basename($script_name, '.' . $path_parts['extension']);
+                }
+                if ($path_parts['dirname'] == '/') {
+                    $path_parts['dirname'] = '';
+                }
+                return $path_parts['dirname'] . '/' . $path_parts['basename'] . SYL_AUTH_PATHINFO;
+            }
+        } else {
+            trigger_error("[SyL error] Unable to get env(_SERVER['REQUEST_URI'] or _SERVER['SCRIPT_NAME'])", E_USER_ERROR);
+        }
     }
 
     /**
      * å󥨥顼̤إ쥯
      * 
+     * @static
+     * @access public
+     * @param string ɲåꥹȥ
+     */
+    function redirectTop($query_string='')
+    {
+        if ($query_string) {
+            $query_string = '?' . $query_string;
+        }
+        SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthUrl')) . $query_string);
+    }
+
+    /**
+     * å󥨥顼URL
+     * 
+     * @static
      * @access public
      */
-    function redirectSessionError()
+    function getAuthSessionErrorUrl()
     {
-        SyL_Response::redirect(SYL_AUTH_SESSION_ERROR_URL);
+        return SYL_AUTH_SESSION_ERROR_URL ? SYL_AUTH_SESSION_ERROR_URL : '/';
+    }
+
+    /**
+     * å󥨥顼̤إ쥯
+     * 
+     * @static
+     * @access public
+     * @param string ɲåꥹȥ
+     */
+    function redirectSessionError($query_string='')
+    {
+        if ($query_string) {
+            $query_string = '?' . $query_string;
+        }
+        SyL_Response::redirect(call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl')) . $query_string);
     }
 
 }
