@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once 'SyL_ViewJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJsLogin.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJsLogin extends SyL_ViewJs
@@ -61,7 +61,7 @@ class SyL_ViewJsLogin extends SyL_ViewJs
     function importJs()
     {
         // ǧڥ֥Ⱥ
-        $this->auth =& SyL_Auth::getInstance();
+        $this->auth =& SyL_Auth::singleton();
 
         list($username, $password) = explode(':', SYL_AUTH_LOGIN_PARAMETER);
         if (SYL_AUTH_PASSWORD_HASH) {
@@ -75,7 +75,6 @@ class SyL_ViewJsLogin extends SyL_ViewJs
         $this->js->import('login');
         $this->js->set('login_username', $username);
         $this->js->set('login_password', $password);
-        $this->js->set('login_url',      SYL_AUTH_LOGIN_URL);
     }
 
 }
