@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.3 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.3 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSqlTableConditions
@@ -132,7 +132,11 @@ class SyL_DBSqlTableConditions
             }
         }
 
-        return implode('', $wheres);
+        if ($or) {
+            return implode('', $wheres) . ') ';
+        } else {
+            return implode('', $wheres);
+        }
     }
 
     /**
