@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.19 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.19 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -784,6 +784,17 @@ class SyL_DB
         }
     }
 
+    /**
+     * ʸޤϾʸȤ
+     *
+     * @access public
+     * @return int ʸޤϾʸ
+     */
+    function getFieldCase()
+    {
+        return $this->field_case;
+    }
+
     /**
      * ̥åΥե̾ʸޤϾʸȤˤ
      *
