@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index
@@ -131,6 +131,9 @@ class Index
              return;
         }
 
+        // Smartyѥ᡼
+        $smarty_flag = is_array($data->get('s'));
+
         if (!is_dir($project_dir)) {
             trigger_error("[SyL error] Project directory not found ({$project_dir})", E_USER_ERROR);
         }
@@ -332,7 +335,11 @@ class Index
         $maintenance_table = 'a';
         $tables[$maintenance_table] = $table_class;
 
+        $i = 1;
         foreach ($schema as $name => $column) {
+            // ʸ
+            $name = strtoupper($name);
+
             if ($column['primary']) {
                 $primary[] = $name;
                 $sorts[]   = "{$maintenance_table}.{$name}.ASC";
@@ -341,12 +348,15 @@ class Index
             $columns[$name]  = '';
             // ե
             $elements[$name] = array(
-              'alias'      => $maintenance_table,
-              'type'       => 'text',
-              'name'       => $name,
-              'attributes' => array('size' => '30'),
-              'validate'   => $this->getValidateDefinition($column)
+              'alias'       => $maintenance_table,
+              'type'        => 'text',
+              'name'        => $name,
+              'attributes'  => array('size' => '30'),
+              'validate'    => $this->getValidateDefinition($column),
+              'sort_list'   => $i,
+              'sort_detail' => $i
             );
+            $i++;
         }
 
         // ơ֥륯饹Ѵ
@@ -497,7 +507,9 @@ class Index
             $file->process(str_replace($form_opp_search, $form_opp_replace, file_get_contents($template_file)));
 
             // ƥץ졼ȥե
-            $template_file = SYL_PROJECT_DIR . '/var/templates/templates/Lst.html';
+            $dir = ($smarty_flag) ? 'smarty' : 'default';
+
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Lst.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}"); ob_flush();
             $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
@@ -505,7 +517,7 @@ class Index
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . '/var/templates/templates/New.html';
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/New.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}"); ob_flush();
             $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
@@ -513,7 +525,7 @@ class Index
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . '/var/templates/templates/Upd.html';
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Upd.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}"); ob_flush();
             $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
@@ -521,7 +533,7 @@ class Index
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . '/var/templates/templates/Fin.html';
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Fin.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}"); ob_flush();
             $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
@@ -529,7 +541,7 @@ class Index
             $file =& SyL_File::factory('w', $create_file);
             $file->process(file_get_contents($template_file));
 
-            $template_file = SYL_PROJECT_DIR . '/var/templates/templates/Vew.html';
+            $template_file = SYL_PROJECT_DIR . "/var/templates/templates/{$dir}/Vew.html";
             $create_file   = "{$template_dir}/" . basename($template_file);
             $cmd->stdout("  template template file {$template_file}"); ob_flush();
             $cmd->stdout("    => generating form file {$create_file}"); ob_flush();
@@ -653,13 +665,7 @@ class Index
         case 'D':
         case 'DT':
             $validate['date'] = array(
-              'message' => '{name}դϤƤ',
-              'parameters' => array(
-                'min' => $column['min'],
-                'max' => $column['max'],
-                'min_error_message' =>  '{name}{min}̤դϤƤ',
-                'max_error_message' =>  '{name}{max}դϤƤ'
-              )
+              'message' => '{name}դϤƤ'
             );
             break;
 
@@ -697,15 +703,16 @@ class Index
     {
         $help = <<<EOF
 Usage:
-  php {$file} -d <dir> -w <name> [-a <dir>] [-c <file>] -t <table> 
+  php {$file} -d <dir> -w <name> [-a <dir>] [-c <file>] -t <table> [-s]
   php {$file} [option]
 
 Options:
   -d <dir>   project directory
   -w <name>  application name
-  -a <dir>   action directory for Adm Application (default: action root directory)
+  -a <dir>   action directory for Adm Application (default: null)
   -c <file>  controller file (default: null)
   -t <table> database table name
+  -s         generate smarty template (default: PHP template)
   -h         show this help, then exit
   -v         output version information, then exit
 EOF;
@@ -750,72 +757,4 @@ EOF;
     }
 }
 
-
-/*
-== PostgreSQL
-
-SELECT 
-  c.relname,
-  c.relkind,
-  a.attname,
-  t.typname,
-  a.atttypmod,
-  a.attnotnull,
-  cs.contype,
-  cs.conrelid, 
-  cs.contypid,
-  cs.confrelid,
-  cs.conkey,
-  cs.confkey
-FROM 
-  pg_class c,
-  pg_attribute a,
-  pg_type t,
-  pg_constraint cs
-WHERE 
-  c.oid = a.attrelid and 
-  a.atttypid = t.oid and 
-  c.relname='users' and 
-  c.oid = cs.conrelid and
-  a.attnum > 0 
-ORDER BY 
-  a.attnum
-
- relname |        attname        |  typname  | atttypmod | attnotnull
----------+-----------------------+-----------+-----------+------------
- users   | users_id              | int4      |        -1 | t
- users   | users_login           | varchar   |        36 | f
- users   | users_password        | varchar   |       132 | f
- users   | users_name            | varchar   |        68 | f
- users   | business_associate_id | int4      |        -1 | f
- users   | warehouse_id          | int4      |        -1 | f
- users   | customers_id          | int4      |        -1 | f
- users   | users_class           | bpchar    |         5 | f
- users   | administrator_flag    | bpchar    |         5 | f
- users   | users_position        | int4      |        -1 | f
- users   | date_added            | timestamp |        -1 | f
- users   | date_last_modified    | timestamp |        -1 | f
- users   | delete_flag           | bpchar    |         5 | f
-
-
-
-select
-  a.attname
-from
-  pg_attribute a,
-  pg_constraint c,
-  pg_class r
-where
-  c.conrelid = r.oid and
-  a.attrelid = r.oid and
-  a.attnum = any (c.conkey) and
-  r.relname = 'users' and 
-  c.contype = 'p';
-
- attname
-----------
- users_id
-
-*/
-
 ?>
